@@ -144,10 +144,6 @@ class NucleusDriver:
         if not self.parser.thread_running:
             self.parser.start()
 
-        if self.parser.nucleus_running and self.parser.thread_running:
-            self.messages.write_warning('Nucleus is already running')
-            return b''
-
         self.logger.get_cp_nc()
         response = self.commands._start()
 
@@ -162,10 +158,6 @@ class NucleusDriver:
         if not self.parser.thread_running:
             self.parser.start()
 
-        if self.parser.nucleus_running and self.parser.thread_running:
-            self.messages.write_warning('Nucleus is already running')
-            return b''
-
         response = self.commands._fieldcal()
 
         self.logging_fieldcal = True
@@ -178,15 +170,15 @@ class NucleusDriver:
             self.messages.write_warning('Nucleus not connected')
             return b''
 
-        if self.parser.thread_running:
-            self.parser.stop()
+        response = self.commands._stop(timeout=3)
 
         if self.logging_fieldcal:
             time.sleep(0.5)
-        response = self.commands._stop(timeout=3)
+
+        if self.parser.thread_running:
+            self.parser.stop()
 
         self.logging_fieldcal = False
-        self.parser.nucleus_running = False
 
         return response
 
